@@ -309,7 +309,7 @@ concordia_helper <- function(x=NULL,tlim=NULL,type=1,
         fit <- concordia.age(X2calc,type=type,exterr=exterr)
     } else if (show.age>1){
         lfit <- ludwig(x2calc,exterr=exterr,model=(show.age-1),anchor=anchor)
-        fit <- concordia.intersection.ludwig(x2calc,fit=lfit,wetherill=(type==1))
+        fit <- discordia(x2calc,fit=lfit,wetherill=(type==1))
     }
     fit$n <- length(x2calc)
     lims <- prepare.concordia.line(x=X2plot,tlim=tlim,type=type,...)
@@ -752,17 +752,18 @@ mswd.concordia <- function(x,cc,type=1,pars,exterr=TRUE){
     names(mswd) <- labels
     names(p.value) <- labels
     names(df) <- labels
-    mswd['equivalence'] <- SS.equivalence/df.equivalence
-    mswd['concordance'] <- SS.concordance/df.concordance
-    mswd['combined'] <- (SS.equivalence+SS.concordance)/
-        (df.equivalence+df.concordance)
-    p.value['equivalence'] <- 1-stats::pchisq(SS.equivalence,df.equivalence)
-    p.value['concordance'] <- 1-stats::pchisq(SS.concordance,df.concordance)
-    p.value['combined'] <- 1-stats::pchisq(SS.equivalence+SS.concordance,
-                                           df.equivalence+df.concordance)
     df['equivalence'] <- df.equivalence
     df['concordance'] <- df.concordance
     df['combined'] <- df.equivalence + df.concordance
+    mswdpequi <- getMSWD(SS.equivalence,df['equivalence'])
+    mswdpconc <- getMSWD(SS.concordance,df['concordance'])
+    mswdpcomb <- getMSWD(SS.equivalence+SS.concordance,df['combined'])
+    mswd['equivalence'] <- mswdpequi$mswd
+    mswd['concordance'] <- mswdpconc$mswd
+    mswd['combined'] <- mswdpcomb$mswd
+    p.value['equivalence'] <- mswdpequi$p.value
+    p.value['concordance'] <- mswdpconc$p.value
+    p.value['combined'] <- mswdpcomb$p.value
     list(mswd=mswd,p.value=p.value,df=df)
 }
 
