@@ -561,7 +561,7 @@ min_age_model <- function(zs,np=3){
     mz <- min(zs[,1])
     Mz <- max(zs[,1])
     cfit <- continuous_mixture(zs[,1],zs[,2])
-    init <- c(mz,0,log(cfit$sigma[1]),0)[1:np]
+    init <- c(mean(c(mz,cfit$mu[1])),0,log(cfit$sigma[1]),0)[1:np]
     ll <- c(mz,-20,init[3]-20,-20)[1:np]
     ul <- c(cfit$mu[1],20,init[3]+2,20)[1:np]
     fit <- stats::optim(init,LL,method='L-BFGS-B',zs=zs,Mz=Mz,lower=ll,upper=ul)
