@@ -480,3 +480,16 @@ contingencyfit <- function(par,fn,lower,upper,hessian=TRUE,control=NULL,...){
     }
     fit
 }
+
+getMSWD <- function(X2,df){
+    out <- list()
+    out$df <- df
+    if (df>0){
+        out$mswd <- as.numeric(X2/df)
+        out$p.value <- as.numeric(1-stats::pchisq(X2,df))
+    } else {
+        out$mswd <- 1
+        out$p.value <- 1
+    }
+    out
+}
